@@ -1,10 +1,29 @@
 #Acoustic Diversity Index from Villanueva-Rivera \emph{et al.} 2011. 
 # The ADI is calculated by dividing the spectrogram into bins (default 10) and taking the proportion of the signals in each bin above a threshold (default -50 dBFS). The ADI is the result of the Shannon index applied to these bins.
 
-acoustic_diversity <- function(soundfile, max_freq = 10000, db_threshold = "-50", freq_step = 1000, shannon = TRUE){
+acoustic_diversity <- function(soundfile, max_freq = 10000, db_threshold = -50, freq_step = 1000, shannon = TRUE){
 
 	db_threshold <- as.numeric(db_threshold)
 	
+	#test arguments
+	if (is.numeric(as.numeric(max_freq))){
+	  max_freq <- as.numeric(max_freq)
+	} else{
+	  stop(" max_freq is not a number.")
+	}
+	
+	if (is.numeric(as.numeric(db_threshold))){
+	  db_threshold <- as.numeric(db_threshold)
+	} else{
+	  stop(" db_threshold is not a number.")
+	}
+	
+	if (is.numeric(as.numeric(freq_step))){
+	  freq_step <- as.numeric(freq_step)
+	} else{
+	  stop(" freq_step is not a number.")
+	}
+	
 	#function that gets the proportion of values over a db value in a specific band
 	# of frequencies. Frequency is in Hz
 	getscore <- function(spectrum, minf, maxf, db, freq_row){
